diff --git a/doc/guix.texi b/doc/guix.texi
index f8e7436cf18bd9c8a1720af4644cdf096549f7df..6b713aaf9c8c9e18b200705d729f463d67c24381 100644
--- a/doc/guix.texi
+++ b/doc/guix.texi
@@ -3646,8 +3646,9 @@ but it supports the following options:
 @item --url=@var{url}
 @itemx --commit=@var{commit}
 @itemx --branch=@var{branch}
-Download code from the specified @var{url}, at the given @var{commit} (a valid
-Git commit ID represented as a hexadecimal string), or @var{branch}.
+Download code for the @code{guix} channel from the specified @var{url}, at the
+given @var{commit} (a valid Git commit ID represented as a hexadecimal
+string), or @var{branch}.
 
 @cindex @file{channels.scm}, configuration file
 @cindex configuration file for channels
diff --git a/guix/channels.scm b/guix/channels.scm
index 9658cf93935d45cef086d0d0ed4c316afe081940..e93879e1b446715d2878871176d0a0507d6d45eb 100644
--- a/guix/channels.scm
+++ b/guix/channels.scm
@@ -52,6 +52,7 @@ (define-module (guix channels)
             channel-location
 
             %default-channels
+            guix-channel?
 
             channel-instance?
             channel-instance-channel
diff --git a/guix/scripts/pull.scm b/guix/scripts/pull.scm
index 55137fce8fa9fa6161426316545e9f89a2fb07a5..71e13686c097e62b7227e3c3146d0c3a1f628239 100644
--- a/guix/scripts/pull.scm
+++ b/guix/scripts/pull.scm
@@ -502,24 +502,22 @@ (define (environment-variable)
         (url (or (assoc-ref opts 'repository-url)
                  (environment-variable))))
     (if (or ref url)
-        (match channels
-          ((one)
-           ;; When there's only one channel, apply '--url', '--commit', and
-           ;; '--branch' to this specific channel.
-           (let ((url (or url (channel-url one))))
-             (list (match ref
+        (match (find guix-channel? channels)
+          ((? channel? guix)
+           ;; Apply '--url', '--commit', and '--branch' to the 'guix' channel.
+           (let ((url (or url (channel-url guix))))
+             (cons (match ref
                      (('commit . commit)
-                      (channel (inherit one)
+                      (channel (inherit guix)
                                (url url) (commit commit) (branch #f)))
                      (('branch . branch)
-                      (channel (inherit one)
+                      (channel (inherit guix)
                                (url url) (commit #f) (branch branch)))
                      (#f
-                      (channel (inherit one) (url url)))))))
-          (_
-           ;; Otherwise bail out.
-           (leave
-            (G_ "'--url', '--commit', and '--branch' are not applicable~%"))))
+                      (channel (inherit guix) (url url))))
+                   (remove guix-channel? channels))))
+          (#f                           ;no 'guix' channel, failure will ensue
+           channels))
         channels)))